Build case_when expression from nodes with predictions and paths
Source:R/tree.R
dot-build_case_when_tree.RdShared helper for building tree expressions used by ranger and randomForest classification extractors.

R/tree.R
dot-build_case_when_tree.RdShared helper for building tree expressions used by ranger and randomForest classification extractors.