dot-build_linear_pred: Build linear predictor expression from coefficient names and...

.build_linear_predR Documentation

Build linear predictor expression from coefficient names and values

Description

Shared helper for building linear predictor strings from coefficients. Used by orbital package for glmnet models.

Usage

.build_linear_pred(coef_names, coef_values)

Arguments

coef_names

Character vector of coefficient names (including "(Intercept)")

coef_values

Numeric vector of coefficient values


tidypredict documentation built on Aug. 24, 2026, 9:10 a.m.